==> haskell-crypto-numbers-0.2.7-67-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-7p9vbn96qbJ4CgpIQcoPGJ
key: crypto-numbers-0.2.7-7p9vbn96qbJ4CgpIQcoPGJ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
abi: 8743684edf30c466379536f0dbfa4370
exposed: True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-7p9vbn96qbJ4CgpIQcoPGJ
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm integer-gmp-1.0.2.0
    ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm=ab3b0f3d326ec2e98980f9a72390f112
             integer-gmp-1.0.2.0=9ea484dc1eeb054803bb4cf8d65c934d
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-74-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-9EDVdg5atZi1RmzYVLL9yl
key: crypto-numbers-0.2.7-9EDVdg5atZi1RmzYVLL9yl
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
abi: 34f7c253b22aa213ac30c9099f074e04
exposed: True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize
import-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-9EDVdg5atZi1RmzYVLL9yl
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    crypto-random-0.0.9-ImEu1YHQEagDk1EizvA7Wq ghc-prim-0.5.3
    integer-gmp-1.0.2.0 vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
